/*****************************************************************************
*
*   Name:   I2C Character LCD Library for use with PCF8574A Port Expander
*
*   Date:   2008.02.24
*   Ver:    1.00
*   Who:    GJO
*
*   History:
*
*   Ver     Date        Who     Description
*   ---------------------------------------------------------------------------
*   1.00    2008.02.24  GJO     Initial Version
*
*
*   HARDWARE INFORMATION:
*   =====================
*
*   LCD used:   LUMEX LCM-S01602DSF/A
*
*   LCD     LCD         IO PINS
*   PIN     FUNCTION    PCF8574A        Comments
*--------------------------------------------------------------------------
*   1       VSS                         GND
*   2       VCC                         +5V
*   3       VO                          10K POT VCC to GND  Contrast Voltage
*   4       RS          P4
*   5       WR                          GND - Busy Detection not used
*   6       E           P7
*   7-10    DB0-3                       Not used - 4-bit mode used
*   11      DB4         P0
*   12      DB5         P1
*   13      DB6         P2
*   14      DB7         P3
*
*   Note: PCF8574A Address pins: A0=A1=A2=0
*
******************************************************************************/

// PCF8574A read and write addresses (A0=A1=A2=0)
#define PCF8574A_WRITE 0x70
#define PCF8574A_READ 0x71

#use i2c(Master, SDA=PIN_H4, SCL=PIN_H5)

#define I2C_SDA         PIN_H4
#define I2C_SCL         PIN_H5

int read_Input_PCF8574A();
void init_PCF8574A();
void set_output_PCF8574A(int);



void init_PCF8574A()
{
   output_high(I2C_SCL);
   output_high(I2C_SDA);
}



void set_output_PCF8574A(int data)
{
   i2c_start();
   i2c_write(PCF8574A_WRITE);
   i2c_write(data);
   i2c_stop();
}



int read_Input_PCF8574A()
{
   int temp=0;
   i2c_start();
   i2c_write(PCF8574A_READ);
   temp = i2c_read(0);
   i2c_stop();
   return(temp);
}



